@@ -199,8 +199,15 @@ class ContractView(BrowserView):
         if contract is not None:
             return contract.expiry_date()
         return None
-    
- 
+
+    def default_start_date(self):
+        """ Takes the current contract expiry data and adds one day.
+        """
+        last_contract_expire = self.expires()
+        if not last_contract_expire:
+            return
+
+        return last_contract_expire + 1
         
     def trial_period_end(self):
         """Return the expiration date of the current contract.
@@ -307,14 +314,14 @@ class ContractViewlet(Explicit, ContractView):
                bool(self.get_functions()) and \
                bool(self.get_employment_types())
 
-    def get_templates(self):
+    def get_templates(self, type='contract'):
         """ Returns the list of available templates.
         """
         tool = getToolByName(self, 'portal_contracts', None)
         if tool is None:
             return []
         else:
-            return tool.listTemplates()
+            return tool.listTemplates(type)
 
     def get_functions(self):
         """Vocabulary for the functions field
